@@ -15,11 +15,11 @@ fi
 BUILD_DIR=build_spades
 BASEDIR=`pwd`/`dirname $0`
 
-rm -rf $BASEDIR/$BUILD_DIR
-mkdir -p $BASEDIR/$BUILD_DIR
+rm -rf "$BASEDIR/$BUILD_DIR"
+mkdir -p "$BASEDIR/$BUILD_DIR"
 set -e
-cd $BASEDIR/$BUILD_DIR
-cmake -G "Unix Makefiles" -DCMAKE_INSTALL_PREFIX=$PREFIX $BASEDIR/src $*
+cd "$BASEDIR/$BUILD_DIR"
+cmake -G "Unix Makefiles" -DCMAKE_INSTALL_PREFIX="$PREFIX" "$BASEDIR/src" $*
 make -j 8
 make install
 cd $PREFIX
